@@ -1,11 +1,11 @@
 package Workflow::Condition;
 
-# $Id: Condition.pm,v 1.4 2004/05/14 05:13:52 cwinters Exp $
+# $Id: Condition.pm,v 1.5 2006/07/08 20:02:33 jonasbn Exp $
 
 use strict;
 use base qw( Workflow::Base );
 
-$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -114,7 +114,7 @@ keep it short!
 
 To create your own condition you should implement the following:
 
-B<_init( \%params )>
+=head3 _init( \%params )
 
 This is optional, but called when the condition is first
 initialized. It may contain information you will want to initialize
@@ -128,12 +128,14 @@ If you do not have sufficient information in C<\%params> you should
 throw an exception (preferably 'configuration_error' imported from
 L<Workflow::Exception>).
 
-B<evaluate( $workflow )>
+=head3 evaluate( $workflow )
 
 Determine whether your condition fails by throwing an exception. You
 can get the application context information necessary to process your
 condition from the C<$workflow> object.
 
+#=head3 init
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003-2004 Chris Winters. All rights reserved.
